summaryrefslogtreecommitdiff
path: root/lisp/textmodes/texinfo.el
diff options
context:
space:
mode:
authorErnest N. Mamikonyan <Ernest.Mamikonyan@sig.com>2020-03-13 10:37:17 -0400
committerEli Zaretskii <eliz@gnu.org>2020-04-03 15:12:47 +0300
commit463f635171683ae3b6907f156305f12fc58ca68e (patch)
tree92084f2617e92a6a0aee4e72a20e4247d73c725d /lisp/textmodes/texinfo.el
parent2c4509179110459f42119ce328d72fea65689288 (diff)
downloademacs-463f635171683ae3b6907f156305f12fc58ca68e.tar.gz
Update texinfo.el following changes in 'tex-start-options-string'
* lisp/textmodes/texinfo.el (texinfo-texi2dvi-options): New defcustom. (texinfo-tex-buffer): Take 'tex-start-options' from 'texinfo-texi2dvi-options'. (Bug#40001) * etc/NEWS: Mention the new option. Copyright-paperwork-exempt: yes
Diffstat (limited to 'lisp/textmodes/texinfo.el')
-rw-r--r--lisp/textmodes/texinfo.el13
1 files changed, 10 insertions, 3 deletions
diff --git a/lisp/textmodes/texinfo.el b/lisp/textmodes/texinfo.el
index 438cb7798a1..66378cb3468 100644
--- a/lisp/textmodes/texinfo.el
+++ b/lisp/textmodes/texinfo.el
@@ -958,6 +958,12 @@ to jump to the corresponding spot in the Texinfo source file."
:type 'string
:group 'texinfo)
+(defcustom texinfo-texi2dvi-options ""
+ "Command line options for `texinfo-texi2dvi-command'."
+ :type 'string
+ :group 'texinfo
+ :version "28.1")
+
(defcustom texinfo-tex-command "tex"
"Command used by `texinfo-tex-region' to run TeX on a region."
:type 'string
@@ -1002,9 +1008,10 @@ The value of `texinfo-tex-trailer' is appended to the temporary file after the r
(interactive)
(require 'tex-mode)
(let ((tex-command texinfo-texi2dvi-command)
- ;; Disable tex-start-options-string. texi2dvi would not
- ;; understand anything specified here.
- (tex-start-options-string ""))
+ (tex-start-options texinfo-texi2dvi-options)
+ ;; Disable tex-start-commands. texi2dvi would not understand
+ ;; anything specified here.
+ (tex-start-commands ""))
(tex-buffer)))
(defun texinfo-texindex ()